//NIST/ITL StRD
//Dataset Name:  Nelson            (Nelson.dat)
//
//File Format:   ASCII
//               Starting Values   (lines 41 to 43)
//               Certified Values  (lines 41 to 48)
//               Data              (lines 61 to 188)
//
//Procedure:     Nonlinear Least Squares Regression
//
//Description:   These data are the result of a study involving
//               the analysis of performance degradation data from
//               accelerated tests, published in IEEE Transactions
//               on Reliability.  The response variable is dialectric
//               breakdown strength in kilo-volts, and the predictor
//               variables are time in weeks and temperature in degrees
//               Celcius.
//
//
//Reference:     Nelson, W. (1981).  
//               Analysis of Performance-Degradation Data.  
//               IEEE Transactions on Reliability.
//               Vol. 2, R-30, No. 2, pp. 149-155.
//
//Data:          1 Response   ( y = dialectric breakdown strength) 
//               2 Predictors (x1 = time; x2 = temperature)
//               128 Observations
//               Average Level of Difficulty
//               Observed Data
//
//Model:         Exponential Class
//               3 Parameters (b1 to b3)
//
//               log[y] = b1 - b2*x1 * exp[-b3*x2]  +  e
funDef='b1 - b2*x1 .* exp(-b3*x2)'; 
dfunDef='[ones(x1),-b2*exp(-b3*x2),b2*(x1).*(x2).*exp(-b3*x2)]';
pDef='b1 b2 b3'; Names='y x1 x2';
deff('yhat=Nelson(b,x)','yhat=b(1) - b(2)*x1 .* exp(-b(3)*x2)');
//
//
//
//          Starting values                  Certified Values
//
//        Start 1     Start 2           Parameter     Standard Deviation
//  b1 =    2           2.5          2.5906836021E+00  1.9149996413E-02
//  b2 =    0.0001      0.000000005  5.6177717026E-09  6.1124096540E-09
//  b3 =   -0.01       -0.05        -5.7701013174E-02  3.9572366543E-03
//
bInit1=[2 0.0001 -0.01]';
bInit2=[2.5 0.000000005 -0.05]';
b=[2.5906836021E+00;5.6177717026E-09;-5.7701013174E-02];
resSS=3.7976833176E+00;
//Residual Sum of Squares:                    3.7976833176E+00
//Residual Standard Deviation:                1.7430280130E-01
//Degrees of Freedom:                               125
//Number of Observations:                           128
//
//
//
//
//
//
//
//
//
//
//
//Data:   y              x1            x2
Data=[
      15.00E0         1E0         180E0
      17.00E0         1E0         180E0
      15.50E0         1E0         180E0
      16.50E0         1E0         180E0
      15.50E0         1E0         225E0
      15.00E0         1E0         225E0
      16.00E0         1E0         225E0
      14.50E0         1E0         225E0
      15.00E0         1E0         250E0
      14.50E0         1E0         250E0
      12.50E0         1E0         250E0
      11.00E0         1E0         250E0
      14.00E0         1E0         275E0
      13.00E0         1E0         275E0
      14.00E0         1E0         275E0
      11.50E0         1E0         275E0
      14.00E0         2E0         180E0
      16.00E0         2E0         180E0
      13.00E0         2E0         180E0
      13.50E0         2E0         180E0
      13.00E0         2E0         225E0
      13.50E0         2E0         225E0
      12.50E0         2E0         225E0
      12.50E0         2E0         225E0
      12.50E0         2E0         250E0
      12.00E0         2E0         250E0
      11.50E0         2E0         250E0
      12.00E0         2E0         250E0
      13.00E0         2E0         275E0
      11.50E0         2E0         275E0
      13.00E0         2E0         275E0
      12.50E0         2E0         275E0
      13.50E0         4E0         180E0
      17.50E0         4E0         180E0
      17.50E0         4E0         180E0
      13.50E0         4E0         180E0
      12.50E0         4E0         225E0
      12.50E0         4E0         225E0
      15.00E0         4E0         225E0
      13.00E0         4E0         225E0
      12.00E0         4E0         250E0
      13.00E0         4E0         250E0
      12.00E0         4E0         250E0
      13.50E0         4E0         250E0
      10.00E0         4E0         275E0
      11.50E0         4E0         275E0
      11.00E0         4E0         275E0
       9.50E0         4E0         275E0
      15.00E0         8E0         180E0
      15.00E0         8E0         180E0
      15.50E0         8E0         180E0
      16.00E0         8E0         180E0
      13.00E0         8E0         225E0
      10.50E0         8E0         225E0
      13.50E0         8E0         225E0
      14.00E0         8E0         225E0
      12.50E0         8E0         250E0
      12.00E0         8E0         250E0
      11.50E0         8E0         250E0
      11.50E0         8E0         250E0
       6.50E0         8E0         275E0
       5.50E0         8E0         275E0
       6.00E0         8E0         275E0
       6.00E0         8E0         275E0
      18.50E0        16E0         180E0
      17.00E0        16E0         180E0
      15.30E0        16E0         180E0
      16.00E0        16E0         180E0
      13.00E0        16E0         225E0
      14.00E0        16E0         225E0
      12.50E0        16E0         225E0
      11.00E0        16E0         225E0
      12.00E0        16E0         250E0
      12.00E0        16E0         250E0
      11.50E0        16E0         250E0
      12.00E0        16E0         250E0
       6.00E0        16E0         275E0
       6.00E0        16E0         275E0
       5.00E0        16E0         275E0
       5.50E0        16E0         275E0
      12.50E0        32E0         180E0
      13.00E0        32E0         180E0
      16.00E0        32E0         180E0
      12.00E0        32E0         180E0
      11.00E0        32E0         225E0
       9.50E0        32E0         225E0
      11.00E0        32E0         225E0
      11.00E0        32E0         225E0
      11.00E0        32E0         250E0
      10.00E0        32E0         250E0
      10.50E0        32E0         250E0
      10.50E0        32E0         250E0
       2.70E0        32E0         275E0
       2.70E0        32E0         275E0
       2.50E0        32E0         275E0
       2.40E0        32E0         275E0
      13.00E0        48E0         180E0
      13.50E0        48E0         180E0
      16.50E0        48E0         180E0
      13.60E0        48E0         180E0
      11.50E0        48E0         225E0
      10.50E0        48E0         225E0
      13.50E0        48E0         225E0
      12.00E0        48E0         225E0
       7.00E0        48E0         250E0
       6.90E0        48E0         250E0
       8.80E0        48E0         250E0
       7.90E0        48E0         250E0
       1.20E0        48E0         275E0
       1.50E0        48E0         275E0
       1.00E0        48E0         275E0
       1.50E0        48E0         275E0
      13.00E0        64E0         180E0
      12.50E0        64E0         180E0
      16.50E0        64E0         180E0
      16.00E0        64E0         180E0
      11.00E0        64E0         225E0
      11.50E0        64E0         225E0
      10.50E0        64E0         225E0
      10.00E0        64E0         225E0
       7.27E0        64E0         250E0
       7.50E0        64E0         250E0
       6.70E0        64E0         250E0
       7.60E0        64E0         250E0
       1.50E0        64E0         275E0
       1.00E0        64E0         275E0
       1.20E0        64E0         275E0
       1.20E0        64E0         275E0
];
Data(:,1) = log(Data(:,1)); 

